summaryrefslogtreecommitdiffstats
path: root/webkit/tools/test_shell/test_shell_mac.mm
diff options
context:
space:
mode:
authordeanm@chromium.org <deanm@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-04 16:54:01 +0000
committerdeanm@chromium.org <deanm@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2008-12-04 16:54:01 +0000
commitbbe0af065171c8c3c226ab45087822d37218fb77 (patch)
tree7094fce066b9c4d1e6eb4822a06884dbb45be67d /webkit/tools/test_shell/test_shell_mac.mm
parentbe8c5ad496da6dabb5d3689b0613348fffbed4c9 (diff)
downloadchromium_src-bbe0af065171c8c3c226ab45087822d37218fb77.zip
chromium_src-bbe0af065171c8c3c226ab45087822d37218fb77.tar.gz
chromium_src-bbe0af065171c8c3c226ab45087822d37218fb77.tar.bz2
Unify on "layout test mode" vs "interactive" and "non-interactive". We had a layout test mode flag in some places, and an interactive flag in others. It was especially confusing since interactive = !layout_test_mode.
This should make it much easier to grep for difference between layout test mode and normal "interactive" mode. Review URL: http://codereview.chromium.org/12940 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@6357 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit/tools/test_shell/test_shell_mac.mm')
-rw-r--r--webkit/tools/test_shell/test_shell_mac.mm10
1 files changed, 5 insertions, 5 deletions
diff --git a/webkit/tools/test_shell/test_shell_mac.mm b/webkit/tools/test_shell/test_shell_mac.mm
index d4603ea..a593501 100644
--- a/webkit/tools/test_shell/test_shell_mac.mm
+++ b/webkit/tools/test_shell/test_shell_mac.mm
@@ -51,8 +51,8 @@ const int kTestWindowHeight = 600;
const int kSVGTestWindowWidth = 480;
const int kSVGTestWindowHeight = 360;
// Hide the window offscreen when it is non-interactive. Mac OS X limits
// window positions to +/- 16000
const int kTestWindowXLocation = -14000;
const int kTestWindowYLocation = -14000;
@@ -127,9 +127,9 @@ void TestShell::PlatformShutdown() {
}
// static
-void TestShell::InitializeTestShell(bool interactive) {
+void TestShell::InitializeTestShell(bool layout_test_mode) {
window_list_ = new WindowList;
- interactive_ = interactive;
+ layout_test_mode_ = layout_test_mode;
web_prefs_ = new WebPreferences;
@@ -524,7 +524,7 @@ void TestShell::LoadURLForFrame(const wchar_t* url,
SizeTo(kSVGTestWindowWidth, kSVGTestWindowHeight);
} else {
// only resize back to the default when running tests
- if (!interactive())
+ if (layout_test_mode())
SizeToDefault();
}
@@ -51,8 +51,8 @@ const int kTestWindowHeight = 600;
const int kSVGTestWindowWidth = 480;
const int kSVGTestWindowHeight = 360;
-// Hide the window offscreen when it is non-interactive. Mac OS X limits
-// window positions to +/- 16000
+// Hide the window offscreen when in layout test mode. Mac OS X limits
+// window positions to +/- 16000.
const int kTestWindowXLocation = -14000;
const int kTestWindowYLocation = -14000;